@@ -21,8 +21,8 @@ class Api(object):
         """
         node_list = self.db_client.env_resource.get_nodes()
         if ip is not None:
-            node_list = [node for node in node_list if node["ip"]==ip]
-        for index,item in enumerate(node_list):
+            node_list = [node for node in node_list if (node["ip"] == ip and node["port"] == port)]
+        for index, item in enumerate(node_list):
             rest_client = RestClient(item["ip"], port)
             ret = rest_client.state.get_state()
             node_list[index]["state"] = ret["data"][0] if ret["state"] == 1 else "offline"
