@@ -13,6 +13,7 @@ from resources.oakgate_resource import OakgateResource
 from resources.stop_flag_resource import StopFlagResource
 from resources.git_resource import GitResource
 from resources.upgrade_resource import UpgradeResource
+from resources.firmware_build_resource import FirmwareBuildResource
 
 
 class RestClient(object):
@@ -28,3 +29,13 @@ class RestClient(object):
         self.stop_flag = StopFlagResource(host, port, __session, time_out)
         self.git = GitResource(host, port, __session, time_out)
         self.upgrade = UpgradeResource(host, port, __session, time_out)
+        self.firmware_build = FirmwareBuildResource(host, port, __session, time_out)
+
+
+if __name__ == '__main__':
+    rest = RestClient("172.29.131.62")
+
+    result = rest.test.get_async_result("yCe3XWvudA")
+    print(result)
+    pass
+
